#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-JpVyJ8mosujASoTdB9Rubc
key:                  ghcide-2.3.0.0-JpVyJ8mosujASoTdB9Rubc
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  e418d3938bed05f0645b9a9591647177
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-JpVyJ8mosujASoTdB9Rubc
depends:
    Diff-0.5-HaIInNZn1yyD00Bv91y4Rt Glob-0.10.2-1WVEJLZs2YoGlZTd7GeDFp
    aeson-2.2.2.0-CuqyF0GV84l91XsdnO7HOm array-0.5.6.0
    async-2.2.6-JvoT9znxQt2BsREADqk9DD base-4.18.2.1
    base16-bytestring-1.0.2.0-foJ0cLokH36TuDy5qj9u binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-Eh88MLcrDxqA6puekTfvJo
    co-log-core-0.3.2.6-LFbRNDIMHZ8JFFwDSu2L06 containers-0.6.7
    cryptohash-sha1-0.11.101.0-FhBT6ylasXuA7limmVczUY
    data-default-0.7.1.3-EBr9yihfmglqiJThokEFL deepseq-1.4.8.1
    dependent-map-0.4.0.1-I2tcslduHqIQV63MDyWbj
    dependent-sum-0.7.2.0-IVnMyHhYs41LYjdljHHM3A directory-1.3.8.5
    dlist-1.0-HIzSgqRZHiKsjIDkWs7Jg
    enummapset-0.7.3.0-8gIYKthN1xn9oTQLyA9X8q exceptions-0.10.7
    extra-1.7.16-9jmcA0IdNtHBNVuTvKhJcq filepath-1.4.300.1
    fingertree-0.1.6.3-AEJHY92aN2TAv7s7kfVr3C
    focus-1.0.3.2-4uHbcHo5vwu7R9kFa6yXCx ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-HGti8w9Tl7CB8JeuCd6hRK
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-DHeSdlBRbkMKsUrX1sqBsA
    hashable-1.4.7.0-8kdP0hepiCNIVGgwFVweHE
    hie-bios-0.12.0-CODoQDzSIs18vMLkN0FPu7
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-9GeZdNRB3XPIhARb2CfQ63
    hls-graph-2.3.0.0-3wyhIKi1lFkAxX3TgjU1gJ
    hls-plugin-api-2.3.0.0-CVlAebno3ls9zFxI5yr51d
    implicit-hie-0.1.4.0-7mTVZcmUf35EFdUtpHRTOu
    implicit-hie-cradle-0.5.0.1-1Z9ke4yvjsS8FCLx4osCrB
    lens-5.3.4-AIhP2tgqTtI4periiO8TOY
    list-t-1.0.5.7-2R7jLVaopLQHqGR2qHQBbn
    lsp-2.2.0.0-1X9YJaCHG0VDE34L6Es6OV
    lsp-types-2.0.2.0-AyUWYbsGMu8KxNnlCqkBNx mtl-2.3.1
    opentelemetry-0.8.0-B3iyNxwgMvIIu569U67oV4
    optparse-applicative-0.18.1.0-HIDucWLVsMnBph0dP0V3D6
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-FXUWMyidK0kKTeGVgF64vT
    prettyprinter-ansi-terminal-1.1.4-LONPuU46hud1w2ZeEL3ScF
    random-1.2.1.3-Lghf55MzNhHBpx4j4jRaDh
    regex-tdfa-1.3.2.5-AvdfaJ7YsJ1IGV7skEbGGt
    row-types-1.0.1.2-IY9kZevmTa55W6Lp06ZbUR
    safe-exceptions-0.1.7.4-AJi6AhcOU2XILudArjgfZI
    sorted-list-0.2.3.1-FpktFJTRUZFMc0z1sR8tL
    sqlite-simple-0.4.19.0-1b8uJwPAaM02sxo6TTUme0 stm-2.5.1.0
    stm-containers-1.2.1.1-GRF0COPrtX8FzrC4JpJvpG
    syb-0.7.3-9ztCG0Q7snPDhcPoUMdZvi text-2.0.2
    text-rope-0.3-JL98zwxV4uuLaQbC7ViWyZ time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-HApsccGPE7G7ELf7BVsYjp
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-owJOmMRhDW8XCXGWMsAkD
    vector-0.13.2.0-KHhvLzyWGFJKP6boEp8Bp2

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

